#ifndef FONTS_H_
#define FONTS_H_
/*
 * $Id: fonts.h 2012-12-30  10:52:34 ssk  $
 *
 * This program is part of TIANMA TM13265LBCWG with 132x65 Graphic LCD Tutorial.
 * Designed for NOVATEK NT7502 65 x 132 RAM-Map LCD Controller/Driver based LCDs on Atmels AVR MCUs
 *
 * Copyright (C) 2012  ssk.
 *
 * Originally Adapted from
 *    Most Functions   : GLCD Version 3 (Beta) Jun 9 2010 <http://arduino.cc/forum/index.php/topic,22208.0.html>
 *    Font Function&Data: Martin Thomas, Kaiserslautern, Germany <eversmith@heizung-thomas.de> 
 *                       avr-gcc 3.4.3/avr-libc 1.2.3 (WinAVR 2/2005)
 *    Cube Drawing     : Osama's Lab KS0108 GLCD library <https://sites.google.com/site/osamaslab>
 *    Line Drawing     : http://en.wikipedia.org/wiki/Bresenham's_line_algorithm
 *    Circle Drawing   : http://en.wikipedia.org/wiki/Midpoint_circle_algorithm
 *
 *
 * Changed & added additional constants for gcc version 4.3.3 (WinAVR 20100110), improved speed and optimized code
 * You need to be selective about the information you receive instead of accepting it unconditionally.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
*/

/*
 *  Original from gText.h - Support for Text output on a graphical device
 *  Copyright (c) 2009,2010  Bill Perry and Michael Margolis
 */
 
/*
 * Copyright:      Fabian Maximilian Thiele  mailto:me@apetech.de
 * Author:         Fabian Maximilian Thiele
 * Remarks:        this Copyright must be included
 * known Problems: none
 * Version:        1.1
 * Description:    Graphic Library for KS0108- (and compatible) based LCDs
 * 
 */
 
#include <avr/pgmspace.h>

typedef uint8_t (*glcd_font_callback)(const uint8_t*);

glcd_font_callback	_glcd_fontread;

uint8_t*  _glcd_font;
uint8_t   _glcd_fontcolor;

// the following returns true if the given font is fixed width
// zero length is flag indicating fixed width font (array does not contain width data entries)
#define isfixedwidthfont(font)  (_glcd_fontread(font+FONT_LENGTH) == 0 && _glcd_fontread(font+FONT_LENGTH+1) == 0)
 
//extern void glcd_selectfont(const char* font, glcd_font_callback callback, uint8_t color);
extern void glcd_selectfont(uint8_t* font, glcd_font_callback callback, uint8_t color);
extern void glcd_puts(char* str);
extern void glcd_puts_P(PGM_P str);
extern uint8_t glcd_readfont(const uint8_t* ptr);		//Standard Read Callback
extern uint8_t glcd_putc(char c);
#endif
