/*
 *
 * System5x7
 *
 *
 * File Name           : System5x7.h
 * Date                : 28 Oct 2008
 * Font size in bytes  : 470
 * Font width          : 5
 * Font height         : 7
 * Font first char     : 32
 * Font last char      : 127
 * Font used chars     : 94
 *
 * The font data are defined as
 *
 * struct _FONT_ {
 *     uint16_t   font_Size_in_Bytes_over_all_included_Size_it_self;
 *     uint8_t    font_Width_in_Pixel_for_fixed_drawing;
 *     uint8_t    font_Height_in_Pixel_for_all_characters;
 *     unit8_t    font_First_Char;
 *     uint8_t    font_Char_Count;
 *
 *     uint8_t    font_Char_Widths[font_Last_Char - font_First_Char +1];
 *                  // for each character the separate width in pixels,
 *                  // characters < 128 have an implicit virtual right empty row
 *
 *     uint8_t    font_data[];
 *                  // bit field of all characters
 */

#include <inttypes.h>
#include <avr/pgmspace.h>

#ifndef SYSTEM5x7_H
#define SYSTEM5x7_H

#define SYSTEM5x7_WIDTH 5
#define SYSTEM5x7_HEIGHT 7

/*
 * added to allow fontname to match header file name. 
 * as well as keep the old name for backward compability
 */

#define SystemFont5x7 System5x7

const uint8_t System5x7[] PROGMEM = {
    0x0, 0x0, // size of zero indicates fixed width font, actual length is width * height
    0x05, // width
    0x07, // height
//    0x08, // height
    0x20, // first char
    0x60, // char count
    
    // Fixed width; char width table not used !!!!

//  0x02,0x02,0x04,0x08,0x04,0x08,0x06,0x02,0x03,0x03,
//  0x06,0x06,0x03,0x04,0x02,0x04,0x05,0x04,0x05,0x05,
//  0x05,0x04,0x05,0x04,0x05,0x05,0x02,0x03,0x04,0x05,
//  0x04,0x04,0x08,0x06,0x05,0x05,0x05,0x04,0x04,0x05,
//  0x05,0x02,0x05,0x05,0x04,0x06,0x06,0x05,0x05,0x05,
//  0x05,0x04,0x04,0x05,0x06,0x08,0x06,0x06,0x04,0x03,
//  0x04,0x03,0x06,0x06,0x03,0x05,0x05,0x04,0x05,0x04,
//  0x04,0x05,0x05,0x02,0x03,0x05,0x02,0x06,0x05,0x05,
//  0x05,0x05,0x04,0x04,0x03,0x05,0x04,0x06,0x04,0x04,
//  0x04,0x04,0x02,0x04,0x07,0x07,
    
  // font data
  0x00, 0x00, 0x00, 0x00, 0x00,// (space) /* ' ' */
	0x00, 0x00, 0x5F, 0x00, 0x00,// !       /* '!' */
	0x00, 0x07, 0x00, 0x07, 0x00,// "       /* '"' */
	0x14, 0x7F, 0x14, 0x7F, 0x14,// #       /* '#' */
	0x24, 0x2A, 0x7F, 0x2A, 0x12,// $       /* '$' */
	0x23, 0x13, 0x08, 0x64, 0x62,// %       /* '%' */
	0x36, 0x49, 0x55, 0x22, 0x50,// &       /* '&' */
	0x00, 0x05, 0x03, 0x00, 0x00,// '       /* ''' */
	0x00, 0x1C, 0x22, 0x41, 0x00,// (       /* '(' */
	0x00, 0x41, 0x22, 0x1C, 0x00,// )       /* ')' */
	0x08, 0x2A, 0x1C, 0x2A, 0x08,// *       /* '*' */
	0x08, 0x08, 0x3E, 0x08, 0x08,// +       /* '+' */
	0x00, 0x50, 0x30, 0x00, 0x00,// ,       /* ',' */
	0x08, 0x08, 0x08, 0x08, 0x08,// -       /* '-' */
	0x00, 0x60, 0x60, 0x00, 0x00,// .       /* '.' */
	0x20, 0x10, 0x08, 0x04, 0x02,// /       /* '/' */
	0x3E, 0x51, 0x49, 0x45, 0x3E,// 0       /* '0' */
	0x00, 0x42, 0x7F, 0x40, 0x00,// 1       /* '1' */
	0x42, 0x61, 0x51, 0x49, 0x46,// 2       /* '2' */
	0x21, 0x41, 0x45, 0x4B, 0x31,// 3       /* '3' */
	0x18, 0x14, 0x12, 0x7F, 0x10,// 4       /* '4' */
	0x27, 0x45, 0x45, 0x45, 0x39,// 5       /* '5' */
	0x3C, 0x4A, 0x49, 0x49, 0x30,// 6       /* '6' */
	0x01, 0x71, 0x09, 0x05, 0x03,// 7       /* '7' */
	0x36, 0x49, 0x49, 0x49, 0x36,// 8       /* '8' */
	0x06, 0x49, 0x49, 0x29, 0x1E,// 9       /* '9' */
	0x00, 0x36, 0x36, 0x00, 0x00,// :       /* ':' */
	0x00, 0x56, 0x36, 0x00, 0x00,// ;       /* ';' */
	0x00, 0x08, 0x14, 0x22, 0x41,// <       /* '<' */
	0x14, 0x14, 0x14, 0x14, 0x14,// =       /* '=' */
	0x41, 0x22, 0x14, 0x08, 0x00,// >       /* '>' */
	0x02, 0x01, 0x51, 0x09, 0x06,// ?       /* '?' */
	0x32, 0x49, 0x79, 0x41, 0x3E,// @       /* '@' */
	0x7E, 0x11, 0x11, 0x11, 0x7E,// A       /* 'A' */
	0x7F, 0x49, 0x49, 0x49, 0x36,// B       /* 'B' */
	0x3E, 0x41, 0x41, 0x41, 0x22,// C       /* 'C' */
	0x7F, 0x41, 0x41, 0x22, 0x1C,// D       /* 'D' */
	0x7F, 0x49, 0x49, 0x49, 0x41,// E       /* 'E' */
	0x7F, 0x09, 0x09, 0x01, 0x01,// F       /* 'F' */
	0x3E, 0x41, 0x41, 0x51, 0x32,// G       /* 'G' */
	0x7F, 0x08, 0x08, 0x08, 0x7F,// H       /* 'H' */
	0x00, 0x41, 0x7F, 0x41, 0x00,// I       /* 'I' */
	0x20, 0x40, 0x41, 0x3F, 0x01,// J       /* 'J' */
	0x7F, 0x08, 0x14, 0x22, 0x41,// K       /* 'K' */
	0x7F, 0x40, 0x40, 0x40, 0x40,// L       /* 'L' */
	0x7F, 0x02, 0x04, 0x02, 0x7F,// M       /* 'M' */
	0x7F, 0x04, 0x08, 0x10, 0x7F,// N       /* 'N' */
	0x3E, 0x41, 0x41, 0x41, 0x3E,// O       /* 'O' */
	0x7F, 0x09, 0x09, 0x09, 0x06,// P       /* 'P' */
	0x3E, 0x41, 0x51, 0x21, 0x5E,// Q       /* 'Q' */
	0x7F, 0x09, 0x19, 0x29, 0x46,// R       /* 'R' */
	0x46, 0x49, 0x49, 0x49, 0x31,// S       /* 'S' */
	0x01, 0x01, 0x7F, 0x01, 0x01,// T       /* 'T' */
	0x3F, 0x40, 0x40, 0x40, 0x3F,// U       /* 'U' */
	0x1F, 0x20, 0x40, 0x20, 0x1F,// V       /* 'V' */
	0x7F, 0x20, 0x18, 0x20, 0x7F,// W       /* 'W' */
	0x63, 0x14, 0x08, 0x14, 0x63,// X       /* 'X' */
	0x03, 0x04, 0x78, 0x04, 0x03,// Y       /* 'Y' */
	0x61, 0x51, 0x49, 0x45, 0x43,// Z       /* 'Z' */
	0x00, 0x00, 0x7F, 0x41, 0x41,// [       /* '[' */
	0x02, 0x04, 0x08, 0x10, 0x20,// "\"     /* '\' */
	0x41, 0x41, 0x7F, 0x00, 0x00,// ]       /* ']' */
	0x04, 0x02, 0x01, 0x02, 0x04,// ^       /* '^' */
	0x40, 0x40, 0x40, 0x40, 0x40,// _       /* '_' */
	0x00, 0x01, 0x02, 0x04, 0x00,// `       /* '`' */
	0x20, 0x54, 0x54, 0x54, 0x78,// a       /* 'a' */
	0x7F, 0x48, 0x44, 0x44, 0x38,// b       /* 'b' */
	0x38, 0x44, 0x44, 0x44, 0x20,// c       /* 'c' */
	0x38, 0x44, 0x44, 0x48, 0x7F,// d       /* 'd' */
	0x38, 0x54, 0x54, 0x54, 0x18,// e       /* 'e' */
	0x08, 0x7E, 0x09, 0x01, 0x02,// f       /* 'f' */
	0x08, 0x14, 0x54, 0x54, 0x3C,// g       /* 'g' */
	0x7F, 0x08, 0x04, 0x04, 0x78,// h       /* 'h' */
	0x00, 0x44, 0x7D, 0x40, 0x00,// i       /* 'i' */
	0x20, 0x40, 0x44, 0x3D, 0x00,// j       /* 'j' */
	0x00, 0x7F, 0x10, 0x28, 0x44,// k       /* 'k' */
	0x00, 0x41, 0x7F, 0x40, 0x00,// l       /* 'l' */
	0x7C, 0x04, 0x18, 0x04, 0x78,// m       /* 'm' */
	0x7C, 0x08, 0x04, 0x04, 0x78,// n       /* 'n' */
	0x38, 0x44, 0x44, 0x44, 0x38,// o       /* 'o' */
	0x7C, 0x14, 0x14, 0x14, 0x08,// p       /* 'p' */
	0x08, 0x14, 0x14, 0x18, 0x7C,// q       /* 'q' */
	0x7C, 0x08, 0x04, 0x04, 0x08,// r       /* 'r' */
	0x48, 0x54, 0x54, 0x54, 0x20,// s       /* 's' */
	0x04, 0x3F, 0x44, 0x40, 0x20,// t       /* 't' */
	0x3C, 0x40, 0x40, 0x20, 0x7C,// u       /* 'u' */
	0x1C, 0x20, 0x40, 0x20, 0x1C,// v       /* 'v' */
	0x3C, 0x40, 0x30, 0x40, 0x3C,// w       /* 'w' */
	0x44, 0x28, 0x10, 0x28, 0x44,// x       /* 'x' */
	0x0C, 0x50, 0x50, 0x50, 0x3C,// y       /* 'y' */
	0x44, 0x64, 0x54, 0x4C, 0x44,// z       /* 'z' */
	0x00, 0x08, 0x36, 0x41, 0x00,// {       /* '{' */
	0x00, 0x00, 0x7F, 0x00, 0x00,// |       /* '|' */
	0x00, 0x41, 0x36, 0x08, 0x00,// }       /* '}' */
	0x08, 0x08, 0x2A, 0x1C, 0x08,// ->      /* '~' */
	0x08, 0x1C, 0x2A, 0x08, 0x08 // <-      
    
};

#endif
