#ifndef SBN166G_H_
#define SBN166G_H_
/*
 * $Id: sbn166g.h 2013/01/27 21:37:53 ssk  $
 *
 * This program is part of Winstar WG20232A-TMI-V#A with 202x32 Graphic LCD Tutorial.
 * Designed for AVANT SBN166G Dot-matrix STN LCD Driver with 32-row x 80-column
 * based LCDs on Atmels AVR MCUs
 *
 * Copyright (C) 2012  ssk.
 *
 * Originally Adapted from
 *    Most Functions   : GLCD Version 3 (Beta) Jun 9 2010 <http://arduino.cc/forum/index.php/topic,22208.0.html>
 *    Font Display&Data: Martin Thomas, Kaiserslautern, Germany <eversmith@heizung-thomas.de> 
 *                       avr-gcc 3.4.3/avr-libc 1.2.3 (WinAVR 2/2005)
 *    Cube Drawing     : Osama's Lab KS0108 GLCD library <https://sites.google.com/site/osamaslab>
 *    Line Drawing     : http://en.wikipedia.org/wiki/Bresenham's_line_algorithm
 *    Circle Drawing   : http://en.wikipedia.org/wiki/Midpoint_circle_algorithm
 *
 *
 * Changed & added additional constants for gcc version 4.3.3 (WinAVR 20100110), improved speed and optimized code
 * You need to be selective about the information you receive instead of accepting it unconditionally.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
*/

/* equate the LCD Controller control signals to their port assignments */
#define LCDDATA_PORT       PORTA
#define LCDDATA_INPUT      PINA
#define LCDDATA_DDR        DDRA
                          
#define LCDCTRL_PORT       PORTC
#define LCDCTRL_DDR        DDRC

#define LCD_A0_PIN         PC4    // Instruction/Data select, H:D0-D7 are display data L:D0-D7 are control data
#define LCD_RW_PIN         PC3    // Read/Write control signal. L:Active (H:Read, L:Write)
#define LCD_CS1_PIN        PC5    // Enable signal (E) for the 68-type microcontroller
#define LCD_CS2_PIN        PC2    // Enable signal (E) for the 68-type microcontroller
#define LCD_CS3_PIN        PC1    // Enable signal (E) for the 68-type microcontroller
#define LCD_RST_PIN        PC6    // THE HARDWARE RESET IS EDGE-SENSITIVE. IT IS NOT LEVEL-SENSITIVE.

/* LCD screen and bitmap image array consants */
#define LCD_X_BYTES		     180
#define LCD_Y_BYTES	       4      // number of page (4page x 8bit = 32)

#define LCD_RIGHT	         179    // the right most pixel         (LCD_X_BYTES - 1)
#define LCD_BOTTOM		     31     // the bottom of pixel         ((LCD_Y_BYTES * 8) -1)

#define LCD_CHIP1_START_X  1      // the CHIP1 start column of pixel
#define LCD_CHIP2_START_X  61     // the CHIP2 start column of pixel
#define LCD_CHIP3_START_X  121    // the CHIP3 start column of pixel

#define LCD_CENTER_X      (LCD_X_BYTES / 2)
#define LCD_CENTER_Y      (LCD_Y_BYTES * 4)    // the row center of pixcel 

// command function equates for SBN166G LCD Display Controller
#define LCD_DISP_OFF       0xAE	  // turn LCD panel OFF
#define LCD_DISP_ON        0xAF	  // turn LCD panel ON
#define LCD_START_LINE     0xC0	  // Specifies RAM line corresponding to top line of display.
#define LCD_SET_PAGE       0xB8	  // set page address
#define LCD_SET_COL        0x00	  // set column address
#define LCD_SET_ADC_NOR    0xA0	  // Column/Segment Mapping Register,  set for normal direction
#define LCD_SET_ADC_REV    0xA1	  // Column/Segment Mapping Register   set for reverse direction
#define LCD_STATIC_OFF     0xA4	  // normal drive
#define LCD_STATIC_ON      0xA5	  // static drive (power save)
#define LCD_DUTY_16        0xA8	  // driving duty 1/16
#define LCD_DUTY_32        0xA9	  // driving duty 1/32
#define LCD_SET_RMW_START  0xE0   // Read-Modify-Write
#define LCD_SET_RMW_END 	 0xEE   // release the Read-Modify-Write
#define LCD_RESET          0xE2	  // soft reset command

/* LCD Color modes */
#define LCD_DOT_CLR        0
#define LCD_DOT_SET        1
#define LCD_DOT_XOR        2

/* LCD Line Style */
#define LCD_LINE_SOLID     0
#define LCD_LINE_DOTTED    1
/*
/* Chip Select
#define LCD_CHIP_1         1
#define LCD_CHIP_2         2
#define LCD_CHIP_3         4
#define LCD_CHIP_ALL       7
*/
/* Chip Select */
#define LCD_CHIP_1         1
#define LCD_CHIP_2         2
#define LCD_CHIP_3         4
#define LCD_CHIP_ALL       7
/*
// defines for panel specific timing  nanosecond (3.3v), using _delay_ns()
#define LCD_tAS            40     // tAS1,2:Address setup time with respect to R/W,C/S,C/D (ctrl line changes to E high)
#define LCD_tDS            160    // Data setup time (Write data lines setup to dropping E)
#define LCD_tACC           200    // Data access time(E high to valid read data)
#define LCD_tEWR           200    // Enable pulse width READ(minimum E hi pulse width)
#define LCD_tEWW           160    // Enable pulse width WRITE(minimum E hi pulse width)
*/
// defines for panel specific timing  nanosecond (3.3v), using _delay_ns()
#define LCD_tAS            20     // tAS1,2:Address setup time with respect to R/W,C/S,C/D (ctrl line changes to E high)
#define LCD_tDS            80    // Data setup time (Write data lines setup to dropping E)
#define LCD_tACC           90    // Data access time(E high to valid read data)
#define LCD_tEWR           100    // Enable pulse width READ(minimum E hi pulse width)
#define LCD_tEWW           80    // Enable pulse width WRITE(minimum E hi pulse width)


typedef struct
{
	uint8_t x;
	uint8_t y;
	uint8_t page;
} coordinates;
coordinates	        _glcd_coord;

// function prototype
extern void glcd_init(void);
extern void glcd_command(const uint8_t command, uint8_t device);
extern void glcd_data(const uint8_t data);
extern void glcd_gotoxy( uint8_t x,  uint8_t y);

extern void glcd_line(uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2, const uint8_t color, const uint8_t style);
              
extern void glcd_hline(uint8_t x1, const uint8_t y1, uint8_t x2, const uint8_t color, const uint8_t style);
extern void glcd_vline(const uint8_t x1, const uint8_t y1, const uint8_t y2, const uint8_t color, const uint8_t style);

extern void glcd_rect(const uint8_t x1, const uint8_t y1, const uint8_t x2, const uint8_t y2, 
                     const uint8_t color, const uint8_t style);
extern void glcd_rect_round(const uint8_t x1, const uint8_t y1, const uint8_t x2, const uint8_t y2, 
                           const uint8_t color, const uint8_t style, const uint8_t radius) ;
extern void glcd_rect_fill(const uint8_t x1, const uint8_t y1, uint8_t x2, const uint8_t y2, const uint8_t color);

extern void glcd_cube(const uint8_t x11, const uint8_t y11, const uint8_t x12, const uint8_t y12, 
                     const uint8_t x21, const uint8_t y21, const uint8_t x22, const uint8_t y22, 
                     const uint8_t color, const uint8_t style);
              
extern void glcd_circle(const uint8_t xcenter, const uint8_t ycenter, const uint8_t radius, const uint8_t color);
extern void glcd_bitmap(uint8_t* bitmap, uint8_t x, uint8_t y,  const uint8_t color);
extern void glcd_puts_ltoa(int32_t value, uint8_t radix, char *str);

#define glcd_clear()       glcd_rect_fill(0,0,LCD_RIGHT,LCD_BOTTOM,LCD_DOT_CLR)
#define _chip_unselect()  (LCDCTRL_PORT &= ~(_BV(LCD_CS1_PIN) | _BV(LCD_CS2_PIN) | _BV(LCD_CS3_PIN)))
#endif
