/*
 * $Id: uart.c 2012-10-24 6:00  ssk  $
 *
 * This program is part of DALLAS DS1721 Temperature Sensor Tutorial.
 *
 * Copyright (C) 2012  ssk.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <avr/pgmspace.h>
#include <avr/io.h>
#include "uart.h"

void uart_init(unsigned int baudrate)
{
//  uart_init(UART_BAUD_SELECT(BAUDRATE,F_CPU));
//  UCSRB = (_BV(TXEN) | _BV(RXEN));
//  UBRRH = 0;
//  UBRRL = baudrate;           // UBRRL = ((F_CPU / (16 * BAUDRATE)) - 1)

  UCSR0B = (_BV(TXEN0) | _BV(RXEN0));
  UBRR0H = 0;
  UBRR0L = baudrate;           // UBRRL = ((F_CPU / (16 * BAUDRATE)) - 1)
  uart_puts_P("\r\n>>> Welcome Debug Mode\r\n");;
}

void uart_putc(uint8_t data)
{
//	loop_until_bit_is_set(UCSRA, UDRE);
//  UDR = data;
	loop_until_bit_is_set(UCSR0A, UDRE0);
  UDR0 = data;
}

void uart_puts(const char *str)
{
  register char c;
  while((c=*str++)) uart_putc(c);

}

uint8_t uart_getc(void)
{
//  loop_until_bit_is_set(UCSRA, RXC);
//  return UDR;
  loop_until_bit_is_set(UCSR0A, RXC0);
  return UDR0;
}

void uart_puts_p(const char *progmem_s)
{
  register char c;
  while((c= pgm_read_byte(progmem_s++))) uart_putc(c);
}

#define NUMBER_OF_DIGITS 32
/*******************************************************************************
convert unsigned long int to characters in LCD
Input:    value unsigned long int number to be displayed
          radix  2(binary),
                10(decimal),
                16(hexadecimal)
Returns:  none
*******************************************************************************/
void uart_puts_ultoa(uint32_t value, uint8_t radix)
{
  uint8_t  index = NUMBER_OF_DIGITS;
  char buffer[NUMBER_OF_DIGITS];    // buffer for NUMBER_OF_DIGITS + '\0'
  do
  {
    buffer[--index] = '0' + (value % radix);
    if ( buffer[index] > '9')
    	 buffer[index] += 'A' - ':';  // continue with A, B,...

    value /= radix;
  } while (value != 0);

  do
  {
  	uart_putc(buffer[index++]);
  } while ( index < NUMBER_OF_DIGITS );
}
/*******************************************************************************
convert signed long int to characters in LCD
Input:    value unsigned long int number to be displayed
          radix  2(binary),
                10(decimal),
                16(hexadecimal)
Returns:  none
*******************************************************************************/
void uart_puts_ltoa(int32_t value, uint8_t radix)
{
  if (value < 0 && radix == 10)
  {
    uart_putc('-');
    uart_puts_ultoa(-value, radix);
  }
  else
    uart_puts_ultoa(value, radix);
}
/*
 * EOF
 */
