/*
 * $Id: uart.h 2012-10-24 6:00  ssk  $
 *
 * This file is part of DALLAS DS1721 Temperature Sensor Tutorial.
 *
 * Copyright (C) 2012  ssk.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef UART_H
#define UART_H

/**
 * \file
 * Functions for accessing the UART in polling mode
 */

#include <avr/pgmspace.h>

#define BAUDRATE 57600
#define UART_BAUD_SELECT(baudRate,xtalCpu) ((xtalCpu)/((baudRate)*16ul)-1)

extern void uart_init(unsigned int baudrate);  // Initialize the uart in polling mode
extern void uart_putc(uint8_t data);           // Send one byte over the uart
extern void uart_puts(const char *str);        // Send a string over the uart
/**
 @brief    convert unsigned long int to characters in LCD
 @param    value unsigned long int number to be displayed
           radix  2(binary),
                10(decimal),
                16(hexadecimal)
 @return   none
*/
extern void uart_puts_ultoa(uint32_t value, uint8_t radix);

/**
 @brief    convert signed long int to characters in LCD
 @param    value signed long int number to be displayed
           radix  2(binary),
                10(decimal),
                16(hexadecimal)
 @return   none
*/
extern void uart_puts_ltoa(int32_t value, uint8_t radix);

extern uint8_t uart_getc(void);                // Receive one byte from the uart
extern void uart_puts_p(const char *progmem_s);// Send a string from program memory over the uart

// macros for automatically storing string constant in program memory
#define uart_puts_P(__s)    uart_puts_p(PSTR(__s));
#endif
